==> sagemaker-0.9.0-sources.jar: software/amazon/awscdk/services/sagemaker/cloudformation/NotebookInstanceLifecycleConfigResourceProps.java <==
package software.amazon.awscdk.services.sagemaker.cloudformation;

/**
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-notebookinstancelifecycleconfig.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.4 (build e80a889)", date = "2018-09-11T09:55:15.539Z")
public interface NotebookInstanceLifecycleConfigResourceProps extends software.amazon.jsii.JsiiSerializable {
    /**
     * ``AWS::SageMaker::NotebookInstanceLifecycleConfig.NotebookInstanceLifecycleConfigName``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-notebookinstancelifecycleconfig.html#cfn-sagemaker-notebookinstancelifecycleconfig-notebookinstancelifecycleconfigname
     */
    java.lang.Object getNotebookInstanceLifecycleConfigName();
    /**
     * ``AWS::SageMaker::NotebookInstanceLifecycleConfig.NotebookInstanceLifecycleConfigName``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-notebookinstancelifecycleconfig.html#cfn-sagemaker-notebookinstancelifecycleconfig-notebookinstancelifecycleconfigname
     */
    void setNotebookInstanceLifecycleConfigName(final java.lang.String value);
    /**
     * ``AWS::SageMaker::NotebookInstanceLifecycleConfig.NotebookInstanceLifecycleConfigName``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-notebookinstancelifecycleconfig.html#cfn-sagemaker-notebookinstancelifecycleconfig-notebookinstancelifecycleconfigname
     */
    void setNotebookInstanceLifecycleConfigName(final software.amazon.awscdk.CloudFormationToken value);
    /**
     * ``AWS::SageMaker::NotebookInstanceLifecycleConfig.OnCreate``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-notebookinstancelifecycleconfig.html#cfn-sagemaker-notebookinstancelifecycleconfig-oncreate
     */
    java.lang.Object getOnCreate();
    /**
     * ``AWS::SageMaker::NotebookInstanceLifecycleConfig.OnCreate``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-notebookinstancelifecycleconfig.html#cfn-sagemaker-notebookinstancelifecycleconfig-oncreate
     */
    void setOnCreate(final software.amazon.awscdk.CloudFormationToken value);
    /**
     * ``AWS::SageMaker::NotebookInstanceLifecycleConfig.OnCreate``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-notebookinstancelifecycleconfig.html#cfn-sagemaker-notebookinstancelifecycleconfig-oncreate
     */
    void setOnCreate(final java.util.List<java.lang.Object> value);
    /**
     * ``AWS::SageMaker::NotebookInstanceLifecycleConfig.OnStart``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-notebookinstancelifecycleconfig.html#cfn-sagemaker-notebookinstancelifecycleconfig-onstart
     */
    java.lang.Object getOnStart();
    /**
     * ``AWS::SageMaker::NotebookInstanceLifecycleConfig.OnStart``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-notebookinstancelifecycleconfig.html#cfn-sagemaker-notebookinstancelifecycleconfig-onstart
     */
    void setOnStart(final software.amazon.awscdk.CloudFormationToken value);
    /**
     * ``AWS::SageMaker::NotebookInstanceLifecycleConfig.OnStart``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-notebookinstancelifecycleconfig.html#cfn-sagemaker-notebookinstancelifecycleconfig-onstart
     */
    void setOnStart(final java.util.List<java.lang.Object> value);

    /**
     * @return a {@link Builder} of {@link NotebookInstanceLifecycleConfigResourceProps}
     */
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link NotebookInstanceLifecycleConfigResourceProps}
     */
    final class Builder {
        @javax.annotation.Nullable
        private java.lang.Object _notebookInstanceLifecycleConfigName;
        @javax.annotation.Nullable
        private java.lang.Object _onCreate;
        @javax.annotation.Nullable
        private java.lang.Object _onStart;

        /**
         * Sets the value of NotebookInstanceLifecycleConfigName
         * @param value ``AWS::SageMaker::NotebookInstanceLifecycleConfig.NotebookInstanceLifecycleConfigName``
         * @return {@code this}
         */
        public Builder withNotebookInstanceLifecycleConfigName(@javax.annotation.Nullable final java.lang.String value) {
            this._notebookInstanceLifecycleConfigName = value;
            return this;
        }
        /**
         * Sets the value of NotebookInstanceLifecycleConfigName
         * @param value ``AWS::SageMaker::NotebookInstanceLifecycleConfig.NotebookInstanceLifecycleConfigName``
         * @return {@code this}
         */
        public Builder withNotebookInstanceLifecycleConfigName(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
            this._notebookInstanceLifecycleConfigName = value;
            return this;
        }
        /**
         * Sets the value of OnCreate
         * @param value ``AWS::SageMaker::NotebookInstanceLifecycleConfig.OnCreate``
         * @return {@code this}
         */
        public Builder withOnCreate(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
            this._onCreate = value;
            return this;
        }
        /**
         * Sets the value of OnCreate
         * @param value ``AWS::SageMaker::NotebookInstanceLifecycleConfig.OnCreate``
         * @return {@code this}
         */
        public Builder withOnCreate(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
            this._onCreate = value;
            return this;
        }
        /**
         * Sets the value of OnStart
         * @param value ``AWS::SageMaker::NotebookInstanceLifecycleConfig.OnStart``
         * @return {@code this}
         */
        public Builder withOnStart(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
            this._onStart = value;
            return this;
        }
        /**
         * Sets the value of OnStart
         * @param value ``AWS::SageMaker::NotebookInstanceLifecycleConfig.OnStart``
         * @return {@code this}
         */
        public Builder withOnStart(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
            this._onStart = value;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link NotebookInstanceLifecycleConfigResourceProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        public NotebookInstanceLifecycleConfigResourceProps build() {
            return new NotebookInstanceLifecycleConfigResourceProps() {
                @javax.annotation.Nullable
                private java.lang.Object $notebookInstanceLifecycleConfigName = _notebookInstanceLifecycleConfigName;
                @javax.annotation.Nullable
                private java.lang.Object $onCreate = _onCreate;
                @javax.annotation.Nullable
                private java.lang.Object $onStart = _onStart;

                @Override
                public java.lang.Object getNotebookInstanceLifecycleConfigName() {
                    return this.$notebookInstanceLifecycleConfigName;
                }

                @Override
                public void setNotebookInstanceLifecycleConfigName(@javax.annotation.Nullable final java.lang.String value) {
                    this.$notebookInstanceLifecycleConfigName = value;
                }

                @Override
                public void setNotebookInstanceLifecycleConfigName(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
                    this.$notebookInstanceLifecycleConfigName = value;
                }

                @Override
                public java.lang.Object getOnCreate() {
                    return this.$onCreate;
                }

                @Override
                public void setOnCreate(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
                    this.$onCreate = value;
                }

                @Override
                public void setOnCreate(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
                    this.$onCreate = value;
                }

                @Override
                public java.lang.Object getOnStart() {
                    return this.$onStart;
                }

                @Override
                public void setOnStart(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
                    this.$onStart = value;
                }

                @Override
                public void setOnStart(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
                    this.$onStart = value;
                }

            };
        }
    }

    /**
     * A proxy class which for javascript object literal which adhere to this interface.
     */
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.sagemaker.cloudformation.NotebookInstanceLifecycleConfigResourceProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * ``AWS::SageMaker::NotebookInstanceLifecycleConfig.NotebookInstanceLifecycleConfigName``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-notebookinstancelifecycleconfig.html#cfn-sagemaker-notebookinstancelifecycleconfig-notebookinstancelifecycleconfigname
         */
        @Override
        @javax.annotation.Nullable
        public java.lang.Object getNotebookInstanceLifecycleConfigName() {
            return this.jsiiGet("notebookInstanceLifecycleConfigName", java.lang.Object.class);
        }

        /**
         * ``AWS::SageMaker::NotebookInstanceLifecycleConfig.NotebookInstanceLifecycleConfigName``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-notebookinstancelifecycleconfig.html#cfn-sagemaker-notebookinstancelifecycleconfig-notebookinstancelifecycleconfigname
         */
        @Override
        public void setNotebookInstanceLifecycleConfigName(@javax.annotation.Nullable final java.lang.String value) {
            this.jsiiSet("notebookInstanceLifecycleConfigName", value);
        }

        /**
         * ``AWS::SageMaker::NotebookInstanceLifecycleConfig.NotebookInstanceLifecycleConfigName``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-notebookinstancelifecycleconfig.html#cfn-sagemaker-notebookinstancelifecycleconfig-notebookinstancelifecycleconfigname
         */
        @Override
        public void setNotebookInstanceLifecycleConfigName(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
            this.jsiiSet("notebookInstanceLifecycleConfigName", value);
        }

        /**
         * ``AWS::SageMaker::NotebookInstanceLifecycleConfig.OnCreate``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-notebookinstancelifecycleconfig.html#cfn-sagemaker-notebookinstancelifecycleconfig-oncreate
         */
        @Override
        @javax.annotation.Nullable
        public java.lang.Object getOnCreate() {
            return this.jsiiGet("onCreate", java.lang.Object.class);
        }

        /**
         * ``AWS::SageMaker::NotebookInstanceLifecycleConfig.OnCreate``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-notebookinstancelifecycleconfig.html#cfn-sagemaker-notebookinstancelifecycleconfig-oncreate
         */
        @Override
        public void setOnCreate(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
            this.jsiiSet("onCreate", value);
        }

        /**
         * ``AWS::SageMaker::NotebookInstanceLifecycleConfig.OnCreate``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-notebookinstancelifecycleconfig.html#cfn-sagemaker-notebookinstancelifecycleconfig-oncreate
         */
        @Override
        public void setOnCreate(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
            this.jsiiSet("onCreate", value);
        }

        /**
         * ``AWS::SageMaker::NotebookInstanceLifecycleConfig.OnStart``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-notebookinstancelifecycleconfig.html#cfn-sagemaker-notebookinstancelifecycleconfig-onstart
         */
        @Override
        @javax.annotation.Nullable
        public java.lang.Object getOnStart() {
            return this.jsiiGet("onStart", java.lang.Object.class);
        }

        /**
         * ``AWS::SageMaker::NotebookInstanceLifecycleConfig.OnStart``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-notebookinstancelifecycleconfig.html#cfn-sagemaker-notebookinstancelifecycleconfig-onstart
         */
        @Override
        public void setOnStart(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
            this.jsiiSet("onStart", value);
        }

        /**
         * ``AWS::SageMaker::NotebookInstanceLifecycleConfig.OnStart``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-notebookinstancelifecycleconfig.html#cfn-sagemaker-notebookinstancelifecycleconfig-onstart
         */
        @Override
        public void setOnStart(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
            this.jsiiSet("onStart", value);
        }
    }
}

==> sagemaker-0.9.1-sources.jar: software/amazon/awscdk/services/sagemaker/cloudformation/NotebookInstanceLifecycleConfigResourceProps.java <==
package software.amazon.awscdk.services.sagemaker.cloudformation;

/**
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-notebookinstancelifecycleconfig.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.5 (build 845cc48)", date = "2018-09-14T09:15:29.328Z")
public interface NotebookInstanceLifecycleConfigResourceProps extends software.amazon.jsii.JsiiSerializable {
    /**
     * ``AWS::SageMaker::NotebookInstanceLifecycleConfig.NotebookInstanceLifecycleConfigName``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-notebookinstancelifecycleconfig.html#cfn-sagemaker-notebookinstancelifecycleconfig-notebookinstancelifecycleconfigname
     */
    java.lang.Object getNotebookInstanceLifecycleConfigName();
    /**
     * ``AWS::SageMaker::NotebookInstanceLifecycleConfig.NotebookInstanceLifecycleConfigName``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-notebookinstancelifecycleconfig.html#cfn-sagemaker-notebookinstancelifecycleconfig-notebookinstancelifecycleconfigname
     */
    void setNotebookInstanceLifecycleConfigName(final java.lang.String value);
    /**
     * ``AWS::SageMaker::NotebookInstanceLifecycleConfig.NotebookInstanceLifecycleConfigName``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-notebookinstancelifecycleconfig.html#cfn-sagemaker-notebookinstancelifecycleconfig-notebookinstancelifecycleconfigname
     */
    void setNotebookInstanceLifecycleConfigName(final software.amazon.awscdk.CloudFormationToken value);
    /**
     * ``AWS::SageMaker::NotebookInstanceLifecycleConfig.OnCreate``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-notebookinstancelifecycleconfig.html#cfn-sagemaker-notebookinstancelifecycleconfig-oncreate
     */
    java.lang.Object getOnCreate();
    /**
     * ``AWS::SageMaker::NotebookInstanceLifecycleConfig.OnCreate``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-notebookinstancelifecycleconfig.html#cfn-sagemaker-notebookinstancelifecycleconfig-oncreate
     */
    void setOnCreate(final software.amazon.awscdk.CloudFormationToken value);
    /**
     * ``AWS::SageMaker::NotebookInstanceLifecycleConfig.OnCreate``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-notebookinstancelifecycleconfig.html#cfn-sagemaker-notebookinstancelifecycleconfig-oncreate
     */
    void setOnCreate(final java.util.List<java.lang.Object> value);
    /**
     * ``AWS::SageMaker::NotebookInstanceLifecycleConfig.OnStart``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-notebookinstancelifecycleconfig.html#cfn-sagemaker-notebookinstancelifecycleconfig-onstart
     */
    java.lang.Object getOnStart();
    /**
     * ``AWS::SageMaker::NotebookInstanceLifecycleConfig.OnStart``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-notebookinstancelifecycleconfig.html#cfn-sagemaker-notebookinstancelifecycleconfig-onstart
     */
    void setOnStart(final software.amazon.awscdk.CloudFormationToken value);
    /**
     * ``AWS::SageMaker::NotebookInstanceLifecycleConfig.OnStart``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-notebookinstancelifecycleconfig.html#cfn-sagemaker-notebookinstancelifecycleconfig-onstart
     */
    void setOnStart(final java.util.List<java.lang.Object> value);

    /**
     * @return a {@link Builder} of {@link NotebookInstanceLifecycleConfigResourceProps}
     */
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link NotebookInstanceLifecycleConfigResourceProps}
     */
    final class Builder {
        @javax.annotation.Nullable
        private java.lang.Object _notebookInstanceLifecycleConfigName;
        @javax.annotation.Nullable
        private java.lang.Object _onCreate;
        @javax.annotation.Nullable
        private java.lang.Object _onStart;

        /**
         * Sets the value of NotebookInstanceLifecycleConfigName
         * @param value ``AWS::SageMaker::NotebookInstanceLifecycleConfig.NotebookInstanceLifecycleConfigName``
         * @return {@code this}
         */
        public Builder withNotebookInstanceLifecycleConfigName(@javax.annotation.Nullable final java.lang.String value) {
            this._notebookInstanceLifecycleConfigName = value;
            return this;
        }
        /**
         * Sets the value of NotebookInstanceLifecycleConfigName
         * @param value ``AWS::SageMaker::NotebookInstanceLifecycleConfig.NotebookInstanceLifecycleConfigName``
         * @return {@code this}
         */
        public Builder withNotebookInstanceLifecycleConfigName(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
            this._notebookInstanceLifecycleConfigName = value;
            return this;
        }
        /**
         * Sets the value of OnCreate
         * @param value ``AWS::SageMaker::NotebookInstanceLifecycleConfig.OnCreate``
         * @return {@code this}
         */
        public Builder withOnCreate(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
            this._onCreate = value;
            return this;
        }
        /**
         * Sets the value of OnCreate
         * @param value ``AWS::SageMaker::NotebookInstanceLifecycleConfig.OnCreate``
         * @return {@code this}
         */
        public Builder withOnCreate(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
            this._onCreate = value;
            return this;
        }
        /**
         * Sets the value of OnStart
         * @param value ``AWS::SageMaker::NotebookInstanceLifecycleConfig.OnStart``
         * @return {@code this}
         */
        public Builder withOnStart(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
            this._onStart = value;
            return this;
        }
        /**
         * Sets the value of OnStart
         * @param value ``AWS::SageMaker::NotebookInstanceLifecycleConfig.OnStart``
         * @return {@code this}
         */
        public Builder withOnStart(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
            this._onStart = value;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link NotebookInstanceLifecycleConfigResourceProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        public NotebookInstanceLifecycleConfigResourceProps build() {
            return new NotebookInstanceLifecycleConfigResourceProps() {
                @javax.annotation.Nullable
                private java.lang.Object $notebookInstanceLifecycleConfigName = _notebookInstanceLifecycleConfigName;
                @javax.annotation.Nullable
                private java.lang.Object $onCreate = _onCreate;
                @javax.annotation.Nullable
                private java.lang.Object $onStart = _onStart;

                @Override
                public java.lang.Object getNotebookInstanceLifecycleConfigName() {
                    return this.$notebookInstanceLifecycleConfigName;
                }

                @Override
                public void setNotebookInstanceLifecycleConfigName(@javax.annotation.Nullable final java.lang.String value) {
                    this.$notebookInstanceLifecycleConfigName = value;
                }

                @Override
                public void setNotebookInstanceLifecycleConfigName(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
                    this.$notebookInstanceLifecycleConfigName = value;
                }

                @Override
                public java.lang.Object getOnCreate() {
                    return this.$onCreate;
                }

                @Override
                public void setOnCreate(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
                    this.$onCreate = value;
                }

                @Override
                public void setOnCreate(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
                    this.$onCreate = value;
                }

                @Override
                public java.lang.Object getOnStart() {
                    return this.$onStart;
                }

                @Override
                public void setOnStart(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
                    this.$onStart = value;
                }

                @Override
                public void setOnStart(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
                    this.$onStart = value;
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.sagemaker.cloudformation.NotebookInstanceLifecycleConfigResourceProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * ``AWS::SageMaker::NotebookInstanceLifecycleConfig.NotebookInstanceLifecycleConfigName``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-notebookinstancelifecycleconfig.html#cfn-sagemaker-notebookinstancelifecycleconfig-notebookinstancelifecycleconfigname
         */
        @Override
        @javax.annotation.Nullable
        public java.lang.Object getNotebookInstanceLifecycleConfigName() {
            return this.jsiiGet("notebookInstanceLifecycleConfigName", java.lang.Object.class);
        }

        /**
         * ``AWS::SageMaker::NotebookInstanceLifecycleConfig.NotebookInstanceLifecycleConfigName``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-notebookinstancelifecycleconfig.html#cfn-sagemaker-notebookinstancelifecycleconfig-notebookinstancelifecycleconfigname
         */
        @Override
        public void setNotebookInstanceLifecycleConfigName(@javax.annotation.Nullable final java.lang.String value) {
            this.jsiiSet("notebookInstanceLifecycleConfigName", value);
        }

        /**
         * ``AWS::SageMaker::NotebookInstanceLifecycleConfig.NotebookInstanceLifecycleConfigName``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-notebookinstancelifecycleconfig.html#cfn-sagemaker-notebookinstancelifecycleconfig-notebookinstancelifecycleconfigname
         */
        @Override
        public void setNotebookInstanceLifecycleConfigName(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
            this.jsiiSet("notebookInstanceLifecycleConfigName", value);
        }

        /**
         * ``AWS::SageMaker::NotebookInstanceLifecycleConfig.OnCreate``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-notebookinstancelifecycleconfig.html#cfn-sagemaker-notebookinstancelifecycleconfig-oncreate
         */
        @Override
        @javax.annotation.Nullable
        public java.lang.Object getOnCreate() {
            return this.jsiiGet("onCreate", java.lang.Object.class);
        }

        /**
         * ``AWS::SageMaker::NotebookInstanceLifecycleConfig.OnCreate``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-notebookinstancelifecycleconfig.html#cfn-sagemaker-notebookinstancelifecycleconfig-oncreate
         */
        @Override
        public void setOnCreate(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
            this.jsiiSet("onCreate", value);
        }

        /**
         * ``AWS::SageMaker::NotebookInstanceLifecycleConfig.OnCreate``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-notebookinstancelifecycleconfig.html#cfn-sagemaker-notebookinstancelifecycleconfig-oncreate
         */
        @Override
        public void setOnCreate(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
            this.jsiiSet("onCreate", value);
        }

        /**
         * ``AWS::SageMaker::NotebookInstanceLifecycleConfig.OnStart``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-notebookinstancelifecycleconfig.html#cfn-sagemaker-notebookinstancelifecycleconfig-onstart
         */
        @Override
        @javax.annotation.Nullable
        public java.lang.Object getOnStart() {
            return this.jsiiGet("onStart", java.lang.Object.class);
        }

        /**
         * ``AWS::SageMaker::NotebookInstanceLifecycleConfig.OnStart``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-notebookinstancelifecycleconfig.html#cfn-sagemaker-notebookinstancelifecycleconfig-onstart
         */
        @Override
        public void setOnStart(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
            this.jsiiSet("onStart", value);
        }

        /**
         * ``AWS::SageMaker::NotebookInstanceLifecycleConfig.OnStart``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-notebookinstancelifecycleconfig.html#cfn-sagemaker-notebookinstancelifecycleconfig-onstart
         */
        @Override
        public void setOnStart(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
            this.jsiiSet("onStart", value);
        }
    }
}
